@@ -295,6 +295,8 @@ class U1Source(rb.Source):
             return False
         uri_to_use = uri.replace("u1ms://", "http://")
         print "Calling u1musicstore plugin with %s" % uri_to_use
+        shell = self.get_property("shell")
+        shell.props.sourcelist.select(self)
         self.browser.load_store_link(uri_to_use)
         return True
 
